@@ -102,7 +102,7 @@ sub URI {
 
 =head2 $link->url_abs()
 
-Returns the URL as an absolute URL string.
+Returns a L<URI::URL> object for the absolute form of the string.
 
 =cut
 
@@ -112,11 +112,26 @@ sub url_abs {
     return $self->URI->abs;
 }
 
-=head1 COPYRIGHT
+=head1 SEE ALSO
 
-Copyright (c) 2004-2006 Andy Lester. All rights reserved. This program is
-free software; you can redistribute it and/or modify it under the same
-terms as Perl itself.
+L<WWW::Mechanize> and L<WWW::Mechanize::Image>
+
+=head1 COPYRIGHT & LICENSE
+
+Copyright 2004-2010 Andy Lester.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of either:
+
+=over 4
+
+=item * the GNU General Public License as published by the Free
+Software Foundation; either version 1, or (at your option) any later
+version, or
+
+=item * the Artistic License version 2.0.
+
+=back
 
 =cut
 
